package com.zd.laboratory.service;

import java.util.List;

import com.zd.laboratory.domain.LabSubjectHardwarePosition;

/**
 * 实验室硬件位置Service接口
 *
 * @author zd
 * @date 2021-09-16
 */
public interface ILabSubjectHardwarePositionService {
    /**
     * 查询实验室硬件位置
     *
     * @param id 实验室硬件位置主键
     * @return 实验室硬件位置
     */
    public LabSubjectHardwarePosition selectLabSubjectHardwarePositionById(Long id);

    /**
     * 查询实验室硬件位置列表
     *
     * @param labSubjectHardwarePosition 实验室硬件位置
     * @return 实验室硬件位置集合
     */
    public List<LabSubjectHardwarePosition> selectLabSubjectHardwarePositionList(LabSubjectHardwarePosition labSubjectHardwarePosition);

    /**
     * 新增实验室硬件位置
     *
     * @param labSubjectHardwarePosition 实验室硬件位置
     * @return 结果
     */
    public int insertLabSubjectHardwarePosition(LabSubjectHardwarePosition labSubjectHardwarePosition);

    /**
     * 修改实验室硬件位置
     *
     * @param labSubjectHardwarePosition 实验室硬件位置
     * @return 结果
     */
    public int updateLabSubjectHardwarePosition(LabSubjectHardwarePosition labSubjectHardwarePosition);

    /**
     * 批量删除实验室硬件位置
     *
     * @param ids 需要删除的实验室硬件位置主键集合
     * @return 结果
     */
    public int deleteLabSubjectHardwarePositionByIds(Long[] ids);

    /**
     * 删除实验室硬件位置信息
     *
     * @param id 实验室硬件位置主键
     * @return 结果
     */
    public int deleteLabSubjectHardwarePositionById(Long id);
}
