package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabSubjectHardwarePosition;
import com.zd.laboratory.service.ILabSubjectHardwarePositionService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 实验室硬件位置Controller
 *
 * @author zd
 * @date 2021-09-16
 */
@RestController
@Api(tags = "【实验室硬件位置】")
@RequestMapping("/position")
public class LabSubjectHardwarePositionController extends BaseController {
    @Autowired
    private ILabSubjectHardwarePositionService labSubjectHardwarePositionService;

    /**
     * 查询实验室硬件位置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询实验室硬件位置列表")
    public TableDataInfo<LabSubjectHardwarePosition> list(LabSubjectHardwarePosition labSubjectHardwarePosition) {
        startPage();
        List<LabSubjectHardwarePosition> list = labSubjectHardwarePositionService.selectLabSubjectHardwarePositionList(labSubjectHardwarePosition);
        return getDataTable(list);
    }

    /**
     * 导出实验室硬件位置列表
     */
    @ApiOperation(value = "导出实验室硬件位置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.EXPORT)
    @Log(title = "实验室硬件位置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabSubjectHardwarePosition labSubjectHardwarePosition) throws IOException {
        List<LabSubjectHardwarePosition> list = labSubjectHardwarePositionService.selectLabSubjectHardwarePositionList(labSubjectHardwarePosition);
        ExcelUtil<LabSubjectHardwarePosition> util = new ExcelUtil<LabSubjectHardwarePosition>(LabSubjectHardwarePosition.class);
        util.exportExcel(response, list, "实验室硬件位置数据");
    }

    /**
     * 获取实验室硬件位置详细信息
     */
    @ApiOperation(value = "获取实验室硬件位置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabSubjectHardwarePosition> getInfo(@PathVariable("id") Long id) {
        return ResultData.success(labSubjectHardwarePositionService.selectLabSubjectHardwarePositionById(id));
    }

    /**
     * 新增实验室硬件位置
     */
    @ApiOperation(value = "新增实验室硬件位置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.ADD)
    @Log(title = "实验室硬件位置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabSubjectHardwarePosition labSubjectHardwarePosition) {
        return ResultData.result(labSubjectHardwarePositionService.insertLabSubjectHardwarePosition(labSubjectHardwarePosition));
    }

    /**
     * 修改实验室硬件位置
     */
    @ApiOperation(value = "修改实验室硬件位置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.EDIT)
    @Log(title = "实验室硬件位置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabSubjectHardwarePosition labSubjectHardwarePosition) {
        return ResultData.result(labSubjectHardwarePositionService.updateLabSubjectHardwarePosition(labSubjectHardwarePosition));
    }

    /**
     * 删除实验室硬件位置
     */
    @ApiOperation(value = "删除实验室硬件位置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_POSITION + PerFun.REMOVE)
    @Log(title = "实验室硬件位置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids) {
        return ResultData.result(labSubjectHardwarePositionService.deleteLabSubjectHardwarePositionByIds(ids));
    }
}
